@@ -1,6 +1,6 @@
 #
 # ovirt-engine-setup -- ovirt engine setup
-# Copyright (C) 2013 Red Hat, Inc.
+# Copyright (C) 2013-2014 Red Hat, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -21,16 +21,24 @@ from otopi import util
 
 from . import admin
 from . import engine
+from . import firewall
 from . import jasper
+from . import jboss
+from . import protocols
 from . import sso
+from . import database
 
 
 @util.export
 def createPlugins(context):
     admin.Plugin(context=context)
     engine.Plugin(context=context)
+    firewall.Plugin(context=context)
     jasper.Plugin(context=context)
+    jboss.Plugin(context=context)
+    protocols.Plugin(context=context)
     sso.Plugin(context=context)
+    database.Plugin(context=context)
 
 
 # vim: expandtab tabstop=4 shiftwidth=4
